Name:           qupzilla
Version:        1.8.6
Release:        6%{?dist}
Summary:        Modern web browser

# Files in src/lib/opensearch and src/lib/3rdparty are GPLv2+
# Files in src/plugins/MouseGestures/3rdparty are BSD (2 clause)
License:        GPLv3+ and BSD
URL:            http://www.qupzilla.com/
Source0:        https://github.com/QupZilla/qupzilla/releases/download/v1.8.6/QupZilla-1.8.6.tar.xz

BuildRequires:  dbus-devel
BuildRequires:  desktop-file-utils
BuildRequires:  openssl-devel

BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-qtwebkit-devel
BuildRequires:  qt5-qtscript-devel
BuildRequires:  qt5-qttools-devel
BuildRequires:  qtsingleapplication-qt5-devel

%description
QupZilla is modern web browser based on WebKit core and Qt Framework. It is 
designed to be lightweight and fast and offers advanced functions such as
- an integrated advertisement blocker,
- a search engine manager,
- a SSL certificate manager,
- speed dial
- theming support, and
- seamless integration into your desktop environment.

%prep
%setup -qn QupZilla-%{version}

# unbundle qtsingleapplication
rm -fr src/lib/3rdparty/qtsingleapplication
ln -s %{_qt5_headerdir}/QtSolutions src/lib/3rdparty/qtsingleapplication
sed -i 's,include.*qtsingleapplication.*,,' src/plugins.pri
sed -i 's,include.*qtsingleapplication.*,,' src/lib/lib.pro

%build
export QUPZILLA_PREFIX="%{_prefix}/"
export USE_LIBPATH="%{_libdir}"
export DISABLE_DBUS="false"
export PORTABLE_BUILD="false"
export GNOME_INTEGRATION="false"

%{qmake_qt5} CONFIG+=QtSingleApplication

make %{?_smp_mflags}


%install
make install INSTALL_ROOT=%{buildroot}

# translations
%find_lang qt --with-qt
# manually handle remaining ones that are not namespaced
# that find_lang does not parse
for i in %{buildroot}%{_datadir}/qupzilla/locale/*.qm ; do
  lang=$(basename $i .qm)
  if [ "$(echo ${lang} | cut -d_ -f1)" != "qt" ]; then
    file="$(echo ${i} | sed -e "s|^%{buildroot}||g")"
    echo "%lang(${lang}) $file" >> qt.lang
  fi
done


desktop-file-install \
    --add-mime-type="x-scheme-handler/http;x-scheme-handler/https;" \
    --dir=%{buildroot}%{_datadir}/applications \
    %{buildroot}/%{_datadir}/applications/%{name}.desktop

# remove useless plugin
rm -f %{buildroot}%{_libdir}/qupzilla/libTestPlugin.so

%post
/sbin/ldconfig
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f qt.lang
%doc AUTHORS CHANGELOG FAQ README.md
%license COPYRIGHT GPLv3 
%{_bindir}/%{name}
%{_libdir}/libQupZilla.so.*
%{_libdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/bash-completion/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/icons/hicolor/*/*/*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/locale
%{_datadir}/%{name}/themes
%{_datadir}/appdata/qupzilla.appdata.xml
# We don't have a devel package
%exclude %{_libdir}/libQupZilla.so


%changelog
* Mon Jul 20 2015 Raphael Groner <projects.rg@smart.ms> - 1.8.6-6
- unbundle qtsingleapplication (rhbz#1091704)
- remove qt4 build (f20 went EOL)

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Apr 12 2015 Helio Chissini de Castro <helio@kde.org> - 1.8.6-4
- Remove some non legal icons from tarball.

* Wed Mar 11 2015 Helio Chissini de Castro <helio@kde.org> - 1.8.6-3
- Add missing build requires

* Wed Mar 11 2015 Helio Chissini de Castro <helio@kde.org> - 1.8.6-2
- Add missing build requires

* Wed Mar 11 2015 Helio Chissini de Castro <helio@kde.org> - 1.8.6-1
- New pustream version - Repackaged replacing invalid icons
- Make Qt5 as default
- Compile Qt4 only in Fedora 20 or less
- Remove invalid flags

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Feb 18 2014 Christoph Wickert <cwickert@fedoraproject.org> - 1.6.3-1
- Update to 1.6.3

* Fri Sep 27 2013 Christoph Wickert <cwickert@fedoraproject.org> - 1.4.4-1
- Update to 1.4.4

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun May 19 2013 Christoph Wickert <cwickert@fedoraproject.org> - 1.4.3-1
- Update to 1.4.3
- Include new bash-completion file

* Mon Apr 01 2013 Christoph Wickert <cwickert@fedoraproject.org> - 1.4.1-1
- Update to 1.4.1

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Oct 20 2012 Christoph Wickert <cwickert@fedoraproject.org> - 1.3.5-2
- Use new filter setup
- Build with --as-needed
- Preserve timestamps during install
- Add comment about license of the source files

* Sat Oct 06 2012 Christoph Wickert <cwickert@fedoraproject.org> - 1.3.5-1
- Update to 1.3.5
- Enable WebGL (USE_WEBGL)
- Enable geolocation and notifications API (USE_QTWEBKIT_2_2)
- Change icense tag to "GPLv3+ and BSD" (some plugins are BSD licensed)
- Add x-scheme-handlers so qupzilla can be set as default browser
- Filter out private requires and provides
- Include README.md in %%doc

* Mon Apr 30 2012 Christoph Wickert <cwickert@fedoraproject.org> - 1.2.0-1
- Initial package
